@@ -1,4 +1,4 @@
-# Copyright 2013 Eygene A. Ryabinkin.
+# Copyright 2013-2016 Eygene A. Ryabinkin & contributors.
 #
 # Module that holds various global objects.
 
@@ -7,6 +7,7 @@ from offlineimap.utils import const
 # Holds command-line options for OfflineIMAP.
 options = const.ConstProxy()
 
-def set_options (source):
-	""" Sets the source for options variable """
-	options.set_source (source)
+def set_options(source):
+    """Sets the source for options variable."""
+
+    options.set_source(source)
